@@ -17,11 +17,12 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 
-#ifndef __PEAS_DEBUG_H__
-#define __PEAS_DEBUG_H__
+#pragma once
 
 #include <glib.h>
 
@@ -30,5 +31,3 @@ G_BEGIN_DECLS
 void  peas_debug_init (void);
 
 G_END_DECLS
-
-#endif /* __PEAS_DEBUG_H__ */
