@@ -17,21 +17,20 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 
-#ifndef __PEAS_DIRS_H__
-#define __PEAS_DIRS_H__
+#pragma once
 
 #include <glib.h>
 
 G_BEGIN_DECLS
 
-gchar  *peas_dirs_get_data_dir          (void);
-gchar  *peas_dirs_get_lib_dir           (void);
-gchar  *peas_dirs_get_plugin_loader_dir (const gchar *loader_name);
-gchar  *peas_dirs_get_locale_dir        (void);
+char *peas_dirs_get_data_dir          (void);
+char *peas_dirs_get_lib_dir           (void);
+char *peas_dirs_get_plugin_loader_dir (const char *loader_name);
+char *peas_dirs_get_locale_dir        (void);
 
 G_END_DECLS
-
-#endif /* __PEAS_DIRS_H__ */
