@@ -15,10 +15,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __PEAS_I18N_PRIV_H__
-#define __PEAS_I18N_PRIV_H__
+#pragma once
 
 #include <glib.h>
 
@@ -28,5 +29,3 @@ G_BEGIN_DECLS
 #define I_(s) g_intern_string(s)
 
 G_END_DECLS
-
-#endif /* __PEAS_I18N_PRIV_H__ */
