@@ -17,11 +17,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "peas-python-internal.h"
 
@@ -37,8 +37,8 @@ static PyObject *
 failed_fn (PyObject *self,
            PyObject *args)
 {
-  const gchar *msg;
-  gchar *clean_msg;
+  const char *msg;
+  char *clean_msg;
 
   if (!PyArg_ParseTuple (args, "s:Hooks.failed", &msg))
     return NULL;
@@ -63,12 +63,11 @@ static PyMethodDef failed_method_def = {
 gboolean
 peas_python_internal_setup (gboolean already_initialized)
 {
-  const gchar *prgname;
+  const char *prgname;
   GBytes *internal_python = NULL;
   PyObject *builtins_module, *globals, *result;
   PyObject *code = NULL, *failed_method = NULL;
   gboolean success = FALSE;
-  char *localedir = NULL;
 
 #define goto_error_if_failed(cond) \
   G_STMT_START { \
@@ -82,11 +81,7 @@ peas_python_internal_setup (gboolean already_initialized)
   prgname = g_get_prgname ();
   prgname = prgname == NULL ? "" : prgname;
 
-#if PY_MAJOR_VERSION < 3
-  builtins_module = PyImport_ImportModule ("__builtin__");
-#else
   builtins_module = PyImport_ImportModule ("builtins");
-#endif
 
   goto_error_if_failed (builtins_module != NULL);
 
@@ -97,11 +92,7 @@ peas_python_internal_setup (gboolean already_initialized)
    * https://bugzilla.gnome.org/show_bug.cgi?id=673101
    */
   internal_python = g_resources_lookup_data ("/org/gnome/libpeas/loaders/"
-#if PY_MAJOR_VERSION < 3
                                              "python/"
-#else
-                                             "python3/"
-#endif
                                              "internal.py",
                                              G_RESOURCE_LOOKUP_FLAGS_NONE,
                                              NULL);
@@ -194,9 +185,9 @@ peas_python_internal_shutdown (void)
 }
 
 PyObject *
-peas_python_internal_call (const gchar  *name,
+peas_python_internal_call (const char   *name,
                            PyTypeObject *return_type,
-                           const gchar  *format,
+                           const char   *format,
                            ...)
 {
   PyObject *args;
