@@ -25,11 +25,15 @@
 
 #include <glib.h>
 
+/* Disable redundant-decls warning introduced in Python 3.12 */
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wredundant-decls"
 /* _POSIX_C_SOURCE is defined in Python.h and in limits.h included by
  * glib-object.h, so we unset it here to avoid a warning. Yep, that's bad.
  */
 #undef _POSIX_C_SOURCE
 #include <Python.h>
+#pragma GCC diagnostic pop
 
 G_BEGIN_DECLS
 
