@@ -17,10 +17,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __TESTING_EXTENSION_H__
-#define __TESTING_EXTENSION_H__
+#pragma once
 
 #include <libpeas/peas-engine.h>
 
@@ -29,22 +30,15 @@
 G_BEGIN_DECLS
 
 PEAS_TEST_EXPORT
-void testing_extension_basic      (const gchar   *loader);
-
+void testing_extension_basic      (const char    *loader);
 PEAS_TEST_EXPORT
-void testing_extension_callable   (const gchar   *loader);
-
-PEAS_TEST_EXPORT
-void testing_extension_add        (const gchar   *path,
+void testing_extension_add        (const char    *path,
                                    GTestDataFunc  func);
-
-
 PEAS_TEST_EXPORT
-int testing_extension_run_tests   (void);
+int  testing_extension_run_tests  (void);
 
 #define testing_extension_all(loader) \
-  testing_extension_basic (loader); \
-  testing_extension_callable (loader);
+  testing_extension_basic (loader);
 
 /* These macros are here to add loader-specific tests. */
 #define EXTENSION_TEST_NAME(loader, path) \
@@ -59,5 +53,3 @@ int testing_extension_run_tests   (void);
                    (GTestFunc) test_extension_##loader##_##func)
 
 G_END_DECLS
-
-#endif /* __TESTING__EXTENSION_H__ */
